@@ -4,13 +4,10 @@
 import os
 import tempfile
 
-import nose.tools as nt
-
 from traitlets import Unicode
 
 from IPython.core.application import BaseIPythonApplication
 from IPython.testing import decorators as dec
-from IPython.utils import py3compat
 from IPython.utils.tempdir import TemporaryDirectory
 
 
@@ -66,9 +63,8 @@ def test_cli_priority():
             f.write("c.TestApp.test = 'config file'")
 
         app = TestApp()
-        app.initialize(['--profile-dir', td])
-        nt.assert_equal(app.test, 'config file')
+        app.initialize(["--profile-dir", td])
+        assert app.test == "config file"
         app = TestApp()
-        app.initialize(['--profile-dir', td, '--TestApp.test=cli'])
-        nt.assert_equal(app.test, 'cli')
-
+        app.initialize(["--profile-dir", td, "--TestApp.test=cli"])
+        assert app.test == "cli"
